==> haskell-regex-posix-0.96.0.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-posix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-posix
version:              0.96.0.0
visibility:           public
id:                   regex-posix-0.96.0.0-IKn9BVY4w1zAUY9vuvg8Rs
key:                  regex-posix-0.96.0.0-IKn9BVY4w1zAUY9vuvg8Rs
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2010, Christopher Kuklewicz
maintainer:           hvr@gnu.org
author:               Christopher Kuklewicz
synopsis:             POSIX Backend for "Text.Regex" (regex-base)
description:
    The POSIX regex backend for <//hackage.haskell.org/package/regex-base regex-base>.

    The main appeal of this backend is that it'\''s very lightweight due to its reliance on the ubiquitous <https://pubs.opengroup.org/onlinepubs/9699919799/basedefs/regex.h.html POSIX.2 regex> facility that is provided by the standard C library on most POSIX platforms.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  43a56f6d05dd2c44c40b595077c31254
exposed:              True
exposed-modules:
    Text.Regex.Posix Text.Regex.Posix.ByteString
    Text.Regex.Posix.ByteString.Lazy Text.Regex.Posix.Sequence
    Text.Regex.Posix.String Text.Regex.Posix.Wrap

hidden-modules:       Paths_regex_posix
import-dirs:          /usr/lib/ghc-8.8.3/site-local/regex-posix-0.96.0.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/regex-posix-0.96.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/regex-posix-0.96.0.0
hs-libraries:         HSregex-posix-0.96.0.0-IKn9BVY4w1zAUY9vuvg8Rs
depends:
    array-0.5.4.0 base-4.13.0.0 bytestring-0.10.10.0 containers-0.6.2.1
    regex-base-0.94.0.0-DXu8ShLVgKTKig28mYwARV

haddock-interfaces:   /usr/share/doc/haskell-regex-posix/html/regex-posix.haddock
haddock-html:         /usr/share/doc/haskell-regex-posix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-posix-0.96.0.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-posix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-posix
version:              0.96.0.0
visibility:           public
id:                   regex-posix-0.96.0.0-FLfGRWXJuxvLcsUxiVOtne
key:                  regex-posix-0.96.0.0-FLfGRWXJuxvLcsUxiVOtne
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2010, Christopher Kuklewicz
maintainer:           hvr@gnu.org
author:               Christopher Kuklewicz
synopsis:             POSIX Backend for "Text.Regex" (regex-base)
description:
    The POSIX regex backend for <//hackage.haskell.org/package/regex-base regex-base>.

    The main appeal of this backend is that it'\''s very lightweight due to its reliance on the ubiquitous <https://pubs.opengroup.org/onlinepubs/9699919799/basedefs/regex.h.html POSIX.2 regex> facility that is provided by the standard C library on most POSIX platforms.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  df1e849e70eb9ba8c90a1cc8fa526ca3
exposed:              True
exposed-modules:
    Text.Regex.Posix Text.Regex.Posix.ByteString
    Text.Regex.Posix.ByteString.Lazy Text.Regex.Posix.Sequence
    Text.Regex.Posix.String Text.Regex.Posix.Wrap

hidden-modules:       Paths_regex_posix
import-dirs:          /usr/lib/ghc-8.10.1/site-local/regex-posix-0.96.0.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/regex-posix-0.96.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/regex-posix-0.96.0.0
hs-libraries:         HSregex-posix-0.96.0.0-FLfGRWXJuxvLcsUxiVOtne
depends:
    array-0.5.4.0 base-4.14.0.0 bytestring-0.10.10.0 containers-0.6.2.1
    regex-base-0.94.0.0-4NbJQ4nd4yIQAJxu7Rutb

haddock-interfaces:   /usr/share/doc/haskell-regex-posix/html/regex-posix.haddock
haddock-html:         /usr/share/doc/haskell-regex-posix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
